@@ -95,17 +95,38 @@ class AccountProps:
 @jsii.data_type(
     jsii_type="@renovosolutions/cdk-library-aws-organization.OUProps",
     jsii_struct_bases=[],
-    name_mapping={"name": "name"},
+    name_mapping={
+        "name": "name",
+        "allow_merge_on_move": "allowMergeOnMove",
+        "allow_recreate_on_update": "allowRecreateOnUpdate",
+        "import_on_duplicate": "importOnDuplicate",
+    },
 )
 class OUProps:
-    def __init__(self, *, name: builtins.str) -> None:
+    def __init__(
+        self,
+        *,
+        name: builtins.str,
+        allow_merge_on_move: typing.Optional[builtins.bool] = None,
+        allow_recreate_on_update: typing.Optional[builtins.bool] = None,
+        import_on_duplicate: typing.Optional[builtins.bool] = None,
+    ) -> None:
         '''The properties of an OU.
 
         :param name: The name of the OU.
+        :param allow_merge_on_move: Whether or not to merge an OU with a duplicate when an OU is moved between parent OUs. If this is false and the OU already exists an error will be thrown. If this is true and the OU already exists the accounts in the OU will be moved to the existing OU and the duplicate, now empty, OU will be deleted. Default: false
+        :param allow_recreate_on_update: Whether or not a missing OU should be recreated during an update. If this is false and the OU does not exist an error will be thrown when you try to update it.
+        :param import_on_duplicate: Whether or not to import an existing OU if the new OU is a duplicate. If this is false and the OU already exists an error will be thrown. Default: false
         '''
         self._values: typing.Dict[str, typing.Any] = {
             "name": name,
         }
+        if allow_merge_on_move is not None:
+            self._values["allow_merge_on_move"] = allow_merge_on_move
+        if allow_recreate_on_update is not None:
+            self._values["allow_recreate_on_update"] = allow_recreate_on_update
+        if import_on_duplicate is not None:
+            self._values["import_on_duplicate"] = import_on_duplicate
 
     @builtins.property
     def name(self) -> builtins.str:
@@ -114,6 +135,39 @@ class OUProps:
         assert result is not None, "Required property 'name' is missing"
         return typing.cast(builtins.str, result)
 
+    @builtins.property
+    def allow_merge_on_move(self) -> typing.Optional[builtins.bool]:
+        '''Whether or not to merge an OU with a duplicate when an OU is moved between parent OUs.
+
+        If this is false and the OU already exists an error will be thrown.
+        If this is true and the OU already exists the accounts in the OU will be moved to the existing OU
+        and the duplicate, now empty, OU will be deleted.
+
+        :default: false
+        '''
+        result = self._values.get("allow_merge_on_move")
+        return typing.cast(typing.Optional[builtins.bool], result)
+
+    @builtins.property
+    def allow_recreate_on_update(self) -> typing.Optional[builtins.bool]:
+        '''Whether or not a missing OU should be recreated during an update.
+
+        If this is false and the OU does not exist an error will be thrown when you try to update it.
+        '''
+        result = self._values.get("allow_recreate_on_update")
+        return typing.cast(typing.Optional[builtins.bool], result)
+
+    @builtins.property
+    def import_on_duplicate(self) -> typing.Optional[builtins.bool]:
+        '''Whether or not to import an existing OU if the new OU is a duplicate.
+
+        If this is false and the OU already exists an error will be thrown.
+
+        :default: false
+        '''
+        result = self._values.get("import_on_duplicate")
+        return typing.cast(typing.Optional[builtins.bool], result)
+
     def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
 
@@ -126,6 +180,119 @@ class OUProps:
         )
 
 
+@jsii.data_type(
+    jsii_type="@renovosolutions/cdk-library-aws-organization.OUResourceProps",
+    jsii_struct_bases=[OUProps],
+    name_mapping={
+        "name": "name",
+        "allow_merge_on_move": "allowMergeOnMove",
+        "allow_recreate_on_update": "allowRecreateOnUpdate",
+        "import_on_duplicate": "importOnDuplicate",
+        "parent": "parent",
+        "provider": "provider",
+    },
+)
+class OUResourceProps(OUProps):
+    def __init__(
+        self,
+        *,
+        name: builtins.str,
+        allow_merge_on_move: typing.Optional[builtins.bool] = None,
+        allow_recreate_on_update: typing.Optional[builtins.bool] = None,
+        import_on_duplicate: typing.Optional[builtins.bool] = None,
+        parent: typing.Union[builtins.str, "OrganizationOU"],
+        provider: aws_cdk.custom_resources.Provider,
+    ) -> None:
+        '''The properties of an OrganizationOU custom resource.
+
+        :param name: The name of the OU.
+        :param allow_merge_on_move: Whether or not to merge an OU with a duplicate when an OU is moved between parent OUs. If this is false and the OU already exists an error will be thrown. If this is true and the OU already exists the accounts in the OU will be moved to the existing OU and the duplicate, now empty, OU will be deleted. Default: false
+        :param allow_recreate_on_update: Whether or not a missing OU should be recreated during an update. If this is false and the OU does not exist an error will be thrown when you try to update it.
+        :param import_on_duplicate: Whether or not to import an existing OU if the new OU is a duplicate. If this is false and the OU already exists an error will be thrown. Default: false
+        :param parent: The parent OU id.
+        :param provider: The provider to use for the custom resource that will create the OU. You can create a provider with the OrganizationOuProvider class
+        '''
+        self._values: typing.Dict[str, typing.Any] = {
+            "name": name,
+            "parent": parent,
+            "provider": provider,
+        }
+        if allow_merge_on_move is not None:
+            self._values["allow_merge_on_move"] = allow_merge_on_move
+        if allow_recreate_on_update is not None:
+            self._values["allow_recreate_on_update"] = allow_recreate_on_update
+        if import_on_duplicate is not None:
+            self._values["import_on_duplicate"] = import_on_duplicate
+
+    @builtins.property
+    def name(self) -> builtins.str:
+        '''The name of the OU.'''
+        result = self._values.get("name")
+        assert result is not None, "Required property 'name' is missing"
+        return typing.cast(builtins.str, result)
+
+    @builtins.property
+    def allow_merge_on_move(self) -> typing.Optional[builtins.bool]:
+        '''Whether or not to merge an OU with a duplicate when an OU is moved between parent OUs.
+
+        If this is false and the OU already exists an error will be thrown.
+        If this is true and the OU already exists the accounts in the OU will be moved to the existing OU
+        and the duplicate, now empty, OU will be deleted.
+
+        :default: false
+        '''
+        result = self._values.get("allow_merge_on_move")
+        return typing.cast(typing.Optional[builtins.bool], result)
+
+    @builtins.property
+    def allow_recreate_on_update(self) -> typing.Optional[builtins.bool]:
+        '''Whether or not a missing OU should be recreated during an update.
+
+        If this is false and the OU does not exist an error will be thrown when you try to update it.
+        '''
+        result = self._values.get("allow_recreate_on_update")
+        return typing.cast(typing.Optional[builtins.bool], result)
+
+    @builtins.property
+    def import_on_duplicate(self) -> typing.Optional[builtins.bool]:
+        '''Whether or not to import an existing OU if the new OU is a duplicate.
+
+        If this is false and the OU already exists an error will be thrown.
+
+        :default: false
+        '''
+        result = self._values.get("import_on_duplicate")
+        return typing.cast(typing.Optional[builtins.bool], result)
+
+    @builtins.property
+    def parent(self) -> typing.Union[builtins.str, "OrganizationOU"]:
+        '''The parent OU id.'''
+        result = self._values.get("parent")
+        assert result is not None, "Required property 'parent' is missing"
+        return typing.cast(typing.Union[builtins.str, "OrganizationOU"], result)
+
+    @builtins.property
+    def provider(self) -> aws_cdk.custom_resources.Provider:
+        '''The provider to use for the custom resource that will create the OU.
+
+        You can create a provider with the OrganizationOuProvider class
+        '''
+        result = self._values.get("provider")
+        assert result is not None, "Required property 'provider' is missing"
+        return typing.cast(aws_cdk.custom_resources.Provider, result)
+
+    def __eq__(self, rhs: typing.Any) -> builtins.bool:
+        return isinstance(rhs, self.__class__) and rhs._values == self._values
+
+    def __ne__(self, rhs: typing.Any) -> builtins.bool:
+        return not (rhs == self)
+
+    def __repr__(self) -> str:
+        return "OUResourceProps(%s)" % ", ".join(
+            k + "=" + repr(v) for k, v in self._values.items()
+        )
+
+
 @jsii.data_type(
     jsii_type="@renovosolutions/cdk-library-aws-organization.OrgObject",
     jsii_struct_bases=[],
@@ -239,9 +406,9 @@ class OrganizationOU(
         scope: constructs.Construct,
         id: builtins.str,
         *,
-        name: builtins.str,
         parent: typing.Union[builtins.str, "OrganizationOU"],
         provider: aws_cdk.custom_resources.Provider,
+        name: builtins.str,
         allow_merge_on_move: typing.Optional[builtins.bool] = None,
         allow_recreate_on_update: typing.Optional[builtins.bool] = None,
         import_on_duplicate: typing.Optional[builtins.bool] = None,
@@ -249,17 +416,17 @@ class OrganizationOU(
         '''
         :param scope: -
         :param id: -
-        :param name: The name of the OU.
         :param parent: The parent OU id.
         :param provider: The provider to use for the custom resource that will create the OU. You can create a provider with the OrganizationOuProvider class
+        :param name: The name of the OU.
         :param allow_merge_on_move: Whether or not to merge an OU with a duplicate when an OU is moved between parent OUs. If this is false and the OU already exists an error will be thrown. If this is true and the OU already exists the accounts in the OU will be moved to the existing OU and the duplicate, now empty, OU will be deleted. Default: false
         :param allow_recreate_on_update: Whether or not a missing OU should be recreated during an update. If this is false and the OU does not exist an error will be thrown when you try to update it.
         :param import_on_duplicate: Whether or not to import an existing OU if the new OU is a duplicate. If this is false and the OU already exists an error will be thrown. Default: false
         '''
-        props = OrganizationOUProps(
-            name=name,
+        props = OUResourceProps(
             parent=parent,
             provider=provider,
+            name=name,
             allow_merge_on_move=allow_merge_on_move,
             allow_recreate_on_update=allow_recreate_on_update,
             import_on_duplicate=import_on_duplicate,
@@ -273,119 +440,6 @@ class OrganizationOU(
         return typing.cast(aws_cdk.CustomResource, jsii.get(self, "resource"))
 
 
-@jsii.data_type(
-    jsii_type="@renovosolutions/cdk-library-aws-organization.OrganizationOUProps",
-    jsii_struct_bases=[],
-    name_mapping={
-        "name": "name",
-        "parent": "parent",
-        "provider": "provider",
-        "allow_merge_on_move": "allowMergeOnMove",
-        "allow_recreate_on_update": "allowRecreateOnUpdate",
-        "import_on_duplicate": "importOnDuplicate",
-    },
-)
-class OrganizationOUProps:
-    def __init__(
-        self,
-        *,
-        name: builtins.str,
-        parent: typing.Union[builtins.str, OrganizationOU],
-        provider: aws_cdk.custom_resources.Provider,
-        allow_merge_on_move: typing.Optional[builtins.bool] = None,
-        allow_recreate_on_update: typing.Optional[builtins.bool] = None,
-        import_on_duplicate: typing.Optional[builtins.bool] = None,
-    ) -> None:
-        '''The properties of an OrganizationOU custom resource.
-
-        :param name: The name of the OU.
-        :param parent: The parent OU id.
-        :param provider: The provider to use for the custom resource that will create the OU. You can create a provider with the OrganizationOuProvider class
-        :param allow_merge_on_move: Whether or not to merge an OU with a duplicate when an OU is moved between parent OUs. If this is false and the OU already exists an error will be thrown. If this is true and the OU already exists the accounts in the OU will be moved to the existing OU and the duplicate, now empty, OU will be deleted. Default: false
-        :param allow_recreate_on_update: Whether or not a missing OU should be recreated during an update. If this is false and the OU does not exist an error will be thrown when you try to update it.
-        :param import_on_duplicate: Whether or not to import an existing OU if the new OU is a duplicate. If this is false and the OU already exists an error will be thrown. Default: false
-        '''
-        self._values: typing.Dict[str, typing.Any] = {
-            "name": name,
-            "parent": parent,
-            "provider": provider,
-        }
-        if allow_merge_on_move is not None:
-            self._values["allow_merge_on_move"] = allow_merge_on_move
-        if allow_recreate_on_update is not None:
-            self._values["allow_recreate_on_update"] = allow_recreate_on_update
-        if import_on_duplicate is not None:
-            self._values["import_on_duplicate"] = import_on_duplicate
-
-    @builtins.property
-    def name(self) -> builtins.str:
-        '''The name of the OU.'''
-        result = self._values.get("name")
-        assert result is not None, "Required property 'name' is missing"
-        return typing.cast(builtins.str, result)
-
-    @builtins.property
-    def parent(self) -> typing.Union[builtins.str, OrganizationOU]:
-        '''The parent OU id.'''
-        result = self._values.get("parent")
-        assert result is not None, "Required property 'parent' is missing"
-        return typing.cast(typing.Union[builtins.str, OrganizationOU], result)
-
-    @builtins.property
-    def provider(self) -> aws_cdk.custom_resources.Provider:
-        '''The provider to use for the custom resource that will create the OU.
-
-        You can create a provider with the OrganizationOuProvider class
-        '''
-        result = self._values.get("provider")
-        assert result is not None, "Required property 'provider' is missing"
-        return typing.cast(aws_cdk.custom_resources.Provider, result)
-
-    @builtins.property
-    def allow_merge_on_move(self) -> typing.Optional[builtins.bool]:
-        '''Whether or not to merge an OU with a duplicate when an OU is moved between parent OUs.
-
-        If this is false and the OU already exists an error will be thrown.
-        If this is true and the OU already exists the accounts in the OU will be moved to the existing OU
-        and the duplicate, now empty, OU will be deleted.
-
-        :default: false
-        '''
-        result = self._values.get("allow_merge_on_move")
-        return typing.cast(typing.Optional[builtins.bool], result)
-
-    @builtins.property
-    def allow_recreate_on_update(self) -> typing.Optional[builtins.bool]:
-        '''Whether or not a missing OU should be recreated during an update.
-
-        If this is false and the OU does not exist an error will be thrown when you try to update it.
-        '''
-        result = self._values.get("allow_recreate_on_update")
-        return typing.cast(typing.Optional[builtins.bool], result)
-
-    @builtins.property
-    def import_on_duplicate(self) -> typing.Optional[builtins.bool]:
-        '''Whether or not to import an existing OU if the new OU is a duplicate.
-
-        If this is false and the OU already exists an error will be thrown.
-
-        :default: false
-        '''
-        result = self._values.get("import_on_duplicate")
-        return typing.cast(typing.Optional[builtins.bool], result)
-
-    def __eq__(self, rhs: typing.Any) -> builtins.bool:
-        return isinstance(rhs, self.__class__) and rhs._values == self._values
-
-    def __ne__(self, rhs: typing.Any) -> builtins.bool:
-        return not (rhs == self)
-
-    def __repr__(self) -> str:
-        return "OrganizationOUProps(%s)" % ", ".join(
-            k + "=" + repr(v) for k, v in self._values.items()
-        )
-
-
 class OrganizationOUProvider(
     constructs.Construct,
     metaclass=jsii.JSIIMeta,
@@ -454,10 +508,10 @@ class OrganizationOUProviderProps:
 __all__ = [
     "AccountProps",
     "OUProps",
+    "OUResourceProps",
     "OrgObject",
     "OrgObjectTypes",
     "OrganizationOU",
-    "OrganizationOUProps",
     "OrganizationOUProvider",
     "OrganizationOUProviderProps",
 ]
